"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQLAnywhereConnection = exports.SQLAnywhereStatement = void 0;
const sqlanywhere_1 = require("sqlanywhere");
class SQLAnywhereStatement {
    constructor(_statement) {
        this._statement = _statement;
    }
    exec(args) {
        return new Promise((resolve, reject) => {
            this._statement.exec(args, (err, rows) => {
                if (err) {
                    return reject(err);
                }
                resolve(rows);
            });
        });
    }
}
exports.SQLAnywhereStatement = SQLAnywhereStatement;
class SQLAnywhereConnection {
    constructor() {
        this._conn = sqlanywhere_1.createConnection();
    }
    connect(params) {
        return new Promise((resolve, reject) => {
            return this._conn.connect(params, (err) => {
                if (err) {
                    return reject(err);
                }
                resolve(true);
            });
        });
    }
    prepare(sql) {
        return new Promise((resolve, reject) => {
            this._conn.prepare(sql, (err, stmt) => {
                if (err) {
                    return reject(err);
                }
                resolve(new SQLAnywhereStatement(stmt));
            });
        });
    }
    query(sql, params) {
        return new Promise((resolve, reject) => {
            this._conn.exec(sql, params || [], (err, rows) => {
                if (err) {
                    return reject(err);
                }
                resolve(rows);
            });
        });
    }
    commit() {
        return new Promise((resolve, reject) => {
            this._conn.commit((err) => {
                if (err) {
                    return reject(err);
                }
                resolve(true);
            });
        });
    }
    rollback() {
        return new Promise((resolve, reject) => {
            this._conn.rollback((err) => {
                if (err) {
                    reject(err);
                }
                resolve(true);
            });
        });
    }
    close() {
        return new Promise((resolve, reject) => {
            this._conn.close((err) => {
                if (err) {
                    reject(err);
                }
                resolve(true);
            });
        });
    }
}
exports.SQLAnywhereConnection = SQLAnywhereConnection;
//# sourceMappingURL=sqlanywherepromise.js.map